# Security Policy

## Supported Versions

| Version               | Supported          |
| --------------------- | ------------------ |
| 0.1.x                 | ✅                 |
| < 0.1.x               | ❌                 |
| Development releases* | ❌                 |
| Alpha releases*       | ❌                 |
| Beta releases*        | ✅                 |
| Release candidates*   | ✅                 |

> *\*Referring to the latest release of this kind.*

## Reporting a Vulnerability

If you get to find a vulnerability, you have two choices based on the danger which is caused by it.
If you understand by yourself that the vulnerability might cause a lot of danger and may cause destructive actions, **do not open an issue and contact immediately** [Hearot](https://github.com/hearot) via gabriel@hearot.it ([GPG public key](https://hearot.it/gpg.txt)).
Otherwise, it is recommended to [open an issue](https://github.com/hearot/pyrubrum/issues/new?assignees=hearot&labels=assumed-bug&template=bug_report.md&title=%5BBug%5D) using the *Bug report* template.
